@@ -1,4 +1,5 @@
-use atuin_dotfiles::store::{var::VarStore, AliasStore};
+use atuin_dotfiles::store::{AliasStore, var::VarStore};
+use atuin_scripts::store::ScriptStore;
 use eyre::{Context, Result};
 
 use atuin_client::{
@@ -6,9 +7,10 @@ use atuin_client::{
     settings::Settings,
 };
 use atuin_common::record::RecordId;
+use atuin_kv::store::KvStore;
 
-/// This is the only crate that ties together all other crates.
-/// Therefore, it's the only crate where functions tying together all stores can live
+// This is the only crate that ties together all other crates.
+// Therefore, it's the only crate where functions tying together all stores can live
 
 /// Rebuild all stores after a sync
 /// Note: for history, this only does an _incremental_ sync. Hence the need to specify downloaded
@@ -27,14 +29,22 @@ pub async fn build(
 
     let downloaded = downloaded.unwrap_or(&[]);
 
+    let kv_db = atuin_kv::database::Database::new(settings.kv.db_path.clone(), 1.0).await?;
+
     let history_store = HistoryStore::new(store.clone(), host_id, encryption_key);
     let alias_store = AliasStore::new(store.clone(), host_id, encryption_key);
     let var_store = VarStore::new(store.clone(), host_id, encryption_key);
+    let kv_store = KvStore::new(store.clone(), kv_db, host_id, encryption_key);
+    let script_store = ScriptStore::new(store.clone(), host_id, encryption_key);
 
     history_store.incremental_build(db, downloaded).await?;
 
     alias_store.build().await?;
     var_store.build().await?;
+    kv_store.build().await?;
 
+    let script_db =
+        atuin_scripts::database::Database::new(settings.scripts.db_path.clone(), 1.0).await?;
+    script_store.build(script_db).await?;
     Ok(())
 }
